===========================
Contributing to scikit-nano
===========================

As any non-cave-dwelling developer knows, working on a project alone sucks.
Collaboration inspires new ideas, leads to better code, and increases the
longevity of a project. I welcome any and all constructive feedback and
anyone insterested in contributing code, please email me or consider
forking the project on github and submitting your contribution with a
pull request. Thanks!
